@@ -9,5 +9,5 @@ class cjdgQiniu(base):
 
     def token(self, data):
         api_name = "file/qiniu/getUpToken"
-        return self.request((api_name, data))
+        return self.request(api_name, data)
 
